@@ -60,8 +60,11 @@ __all__ = (
     "CreateComputeEnvironmentResponseTypeDef",
     "CreateJobQueueRequestRequestTypeDef",
     "CreateJobQueueResponseTypeDef",
+    "CreateSchedulingPolicyRequestRequestTypeDef",
+    "CreateSchedulingPolicyResponseTypeDef",
     "DeleteComputeEnvironmentRequestRequestTypeDef",
     "DeleteJobQueueRequestRequestTypeDef",
+    "DeleteSchedulingPolicyRequestRequestTypeDef",
     "DeregisterJobDefinitionRequestRequestTypeDef",
     "DescribeComputeEnvironmentsRequestRequestTypeDef",
     "DescribeComputeEnvironmentsResponseTypeDef",
@@ -71,11 +74,14 @@ __all__ = (
     "DescribeJobQueuesResponseTypeDef",
     "DescribeJobsRequestRequestTypeDef",
     "DescribeJobsResponseTypeDef",
+    "DescribeSchedulingPoliciesRequestRequestTypeDef",
+    "DescribeSchedulingPoliciesResponseTypeDef",
     "DeviceTypeDef",
     "EFSAuthorizationConfigTypeDef",
     "EFSVolumeConfigurationTypeDef",
     "Ec2ConfigurationTypeDef",
     "EvaluateOnExitTypeDef",
+    "FairsharePolicyTypeDef",
     "FargatePlatformConfigurationTypeDef",
     "HostTypeDef",
     "JobDefinitionTypeDef",
@@ -90,6 +96,8 @@ __all__ = (
     "LinuxParametersTypeDef",
     "ListJobsRequestRequestTypeDef",
     "ListJobsResponseTypeDef",
+    "ListSchedulingPoliciesRequestRequestTypeDef",
+    "ListSchedulingPoliciesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "LogConfigurationTypeDef",
@@ -108,7 +116,10 @@ __all__ = (
     "ResourceRequirementTypeDef",
     "ResponseMetadataTypeDef",
     "RetryStrategyTypeDef",
+    "SchedulingPolicyDetailTypeDef",
+    "SchedulingPolicyListingDetailTypeDef",
     "SecretTypeDef",
+    "ShareAttributesTypeDef",
     "SubmitJobRequestRequestTypeDef",
     "SubmitJobResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -120,6 +131,7 @@ __all__ = (
     "UpdateComputeEnvironmentResponseTypeDef",
     "UpdateJobQueueRequestRequestTypeDef",
     "UpdateJobQueueResponseTypeDef",
+    "UpdateSchedulingPolicyRequestRequestTypeDef",
     "VolumeTypeDef",
 )
 
@@ -193,6 +205,7 @@ _RequiredComputeEnvironmentDetailTypeDef = TypedDict(
 _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
     "_OptionalComputeEnvironmentDetailTypeDef",
     {
+        "unmanagedvCpus": int,
         "tags": Dict[str, str],
         "type": CETypeType,
         "state": CEStateType,
@@ -358,6 +371,7 @@ _OptionalCreateComputeEnvironmentRequestRequestTypeDef = TypedDict(
     "_OptionalCreateComputeEnvironmentRequestRequestTypeDef",
     {
         "state": CEStateType,
+        "unmanagedvCpus": int,
         "computeResources": "ComputeResourceTypeDef",
         "serviceRole": str,
         "tags": Mapping[str, str],
@@ -394,6 +408,7 @@ _OptionalCreateJobQueueRequestRequestTypeDef = TypedDict(
     "_OptionalCreateJobQueueRequestRequestTypeDef",
     {
         "state": JQStateType,
+        "schedulingPolicyArn": str,
         "tags": Mapping[str, str],
     },
     total=False,
@@ -415,6 +430,38 @@ CreateJobQueueResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateSchedulingPolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSchedulingPolicyRequestRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalCreateSchedulingPolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSchedulingPolicyRequestRequestTypeDef",
+    {
+        "fairsharePolicy": "FairsharePolicyTypeDef",
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateSchedulingPolicyRequestRequestTypeDef(
+    _RequiredCreateSchedulingPolicyRequestRequestTypeDef,
+    _OptionalCreateSchedulingPolicyRequestRequestTypeDef,
+):
+    pass
+
+
+CreateSchedulingPolicyResponseTypeDef = TypedDict(
+    "CreateSchedulingPolicyResponseTypeDef",
+    {
+        "name": str,
+        "arn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DeleteComputeEnvironmentRequestRequestTypeDef = TypedDict(
     "DeleteComputeEnvironmentRequestRequestTypeDef",
     {
@@ -429,6 +476,13 @@ DeleteJobQueueRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteSchedulingPolicyRequestRequestTypeDef = TypedDict(
+    "DeleteSchedulingPolicyRequestRequestTypeDef",
+    {
+        "arn": str,
+    },
+)
+
 DeregisterJobDefinitionRequestRequestTypeDef = TypedDict(
     "DeregisterJobDefinitionRequestRequestTypeDef",
     {
@@ -510,6 +564,21 @@ DescribeJobsResponseTypeDef = TypedDict(
     },
 )
 
+DescribeSchedulingPoliciesRequestRequestTypeDef = TypedDict(
+    "DescribeSchedulingPoliciesRequestRequestTypeDef",
+    {
+        "arns": Sequence[str],
+    },
+)
+
+DescribeSchedulingPoliciesResponseTypeDef = TypedDict(
+    "DescribeSchedulingPoliciesResponseTypeDef",
+    {
+        "schedulingPolicies": List["SchedulingPolicyDetailTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredDeviceTypeDef = TypedDict(
     "_RequiredDeviceTypeDef",
     {
@@ -603,6 +672,16 @@ class EvaluateOnExitTypeDef(_RequiredEvaluateOnExitTypeDef, _OptionalEvaluateOnE
     pass
 
 
+FairsharePolicyTypeDef = TypedDict(
+    "FairsharePolicyTypeDef",
+    {
+        "shareDecaySeconds": int,
+        "computeReservation": int,
+        "shareDistribution": Sequence["ShareAttributesTypeDef"],
+    },
+    total=False,
+)
+
 FargatePlatformConfigurationTypeDef = TypedDict(
     "FargatePlatformConfigurationTypeDef",
     {
@@ -632,6 +711,7 @@ _OptionalJobDefinitionTypeDef = TypedDict(
     "_OptionalJobDefinitionTypeDef",
     {
         "status": str,
+        "schedulingPriority": int,
         "parameters": Dict[str, str],
         "retryStrategy": "RetryStrategyTypeDef",
         "containerProperties": "ContainerPropertiesTypeDef",
@@ -673,6 +753,8 @@ _OptionalJobDetailTypeDef = TypedDict(
     "_OptionalJobDetailTypeDef",
     {
         "jobArn": str,
+        "shareIdentifier": str,
+        "schedulingPriority": int,
         "attempts": List["AttemptDetailTypeDef"],
         "statusReason": str,
         "createdAt": int,
@@ -710,6 +792,7 @@ _RequiredJobQueueDetailTypeDef = TypedDict(
 _OptionalJobQueueDetailTypeDef = TypedDict(
     "_OptionalJobQueueDetailTypeDef",
     {
+        "schedulingPolicyArn": str,
         "status": JQStatusType,
         "statusReason": str,
         "tags": Dict[str, str],
@@ -823,6 +906,24 @@ ListJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListSchedulingPoliciesRequestRequestTypeDef = TypedDict(
+    "ListSchedulingPoliciesRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListSchedulingPoliciesResponseTypeDef = TypedDict(
+    "ListSchedulingPoliciesResponseTypeDef",
+    {
+        "schedulingPolicies": List["SchedulingPolicyListingDetailTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -986,6 +1087,7 @@ _OptionalRegisterJobDefinitionRequestRequestTypeDef = TypedDict(
     "_OptionalRegisterJobDefinitionRequestRequestTypeDef",
     {
         "parameters": Mapping[str, str],
+        "schedulingPriority": int,
         "containerProperties": "ContainerPropertiesTypeDef",
         "nodeProperties": "NodePropertiesTypeDef",
         "retryStrategy": "RetryStrategyTypeDef",
@@ -1043,6 +1145,36 @@ RetryStrategyTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredSchedulingPolicyDetailTypeDef = TypedDict(
+    "_RequiredSchedulingPolicyDetailTypeDef",
+    {
+        "name": str,
+        "arn": str,
+    },
+)
+_OptionalSchedulingPolicyDetailTypeDef = TypedDict(
+    "_OptionalSchedulingPolicyDetailTypeDef",
+    {
+        "fairsharePolicy": "FairsharePolicyTypeDef",
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class SchedulingPolicyDetailTypeDef(
+    _RequiredSchedulingPolicyDetailTypeDef, _OptionalSchedulingPolicyDetailTypeDef
+):
+    pass
+
+
+SchedulingPolicyListingDetailTypeDef = TypedDict(
+    "SchedulingPolicyListingDetailTypeDef",
+    {
+        "arn": str,
+    },
+)
+
 SecretTypeDef = TypedDict(
     "SecretTypeDef",
     {
@@ -1051,6 +1183,25 @@ SecretTypeDef = TypedDict(
     },
 )
 
+_RequiredShareAttributesTypeDef = TypedDict(
+    "_RequiredShareAttributesTypeDef",
+    {
+        "shareIdentifier": str,
+    },
+)
+_OptionalShareAttributesTypeDef = TypedDict(
+    "_OptionalShareAttributesTypeDef",
+    {
+        "weightFactor": float,
+    },
+    total=False,
+)
+
+
+class ShareAttributesTypeDef(_RequiredShareAttributesTypeDef, _OptionalShareAttributesTypeDef):
+    pass
+
+
 _RequiredSubmitJobRequestRequestTypeDef = TypedDict(
     "_RequiredSubmitJobRequestRequestTypeDef",
     {
@@ -1062,6 +1213,8 @@ _RequiredSubmitJobRequestRequestTypeDef = TypedDict(
 _OptionalSubmitJobRequestRequestTypeDef = TypedDict(
     "_OptionalSubmitJobRequestRequestTypeDef",
     {
+        "shareIdentifier": str,
+        "schedulingPriorityOverride": int,
         "arrayProperties": "ArrayPropertiesTypeDef",
         "dependsOn": Sequence["JobDependencyTypeDef"],
         "parameters": Mapping[str, str],
@@ -1155,6 +1308,7 @@ _OptionalUpdateComputeEnvironmentRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateComputeEnvironmentRequestRequestTypeDef",
     {
         "state": CEStateType,
+        "unmanagedvCpus": int,
         "computeResources": "ComputeResourceUpdateTypeDef",
         "serviceRole": str,
     },
@@ -1188,6 +1342,7 @@ _OptionalUpdateJobQueueRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateJobQueueRequestRequestTypeDef",
     {
         "state": JQStateType,
+        "schedulingPolicyArn": str,
         "priority": int,
         "computeEnvironmentOrder": Sequence["ComputeEnvironmentOrderTypeDef"],
     },
@@ -1210,6 +1365,28 @@ UpdateJobQueueResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateSchedulingPolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSchedulingPolicyRequestRequestTypeDef",
+    {
+        "arn": str,
+    },
+)
+_OptionalUpdateSchedulingPolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSchedulingPolicyRequestRequestTypeDef",
+    {
+        "fairsharePolicy": "FairsharePolicyTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateSchedulingPolicyRequestRequestTypeDef(
+    _RequiredUpdateSchedulingPolicyRequestRequestTypeDef,
+    _OptionalUpdateSchedulingPolicyRequestRequestTypeDef,
+):
+    pass
+
+
 VolumeTypeDef = TypedDict(
     "VolumeTypeDef",
     {
